@@ -1,5 +1,5 @@
 __author__ = 'Carrycat'
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 from rest_framework import serializers
 from oauth2_provider.models import AccessToken
 
